## OpsSection

```
A python library for creating openseespy fiber section objects.
```

---

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install OpsSection.

```
pip install opssection
```
---
## Usage

Import OpsSection in your Python code(openseespy project) like this:

```python
import opssection.fibersection as ofs
```


---
## Support
- [Email](mailto:ok.programss@gmail.com)

- [Telegram Channel](https://t.me/OKprograms)

- [Instagram](https://www.instagram.com/opensees_apps/?hl=en)

---
## Author
```
Oktai Alizade Arasi
Master of Science in Structural Engineering
```
---
## Documentation

1- Download from: [OpsSection Documentation](https://drive.google.com/file/d/14YjLMHoF9C2b_RddTJqhrB6e6OWlx4Yt/view?usp=sharing)

2- Use getDoc() method of opssection.fibersection module:
```python
ofs.getDoc()
```

---
## License
```
OSI Approved : MIT License
```
---